jQuery(document).ready(function($) {
    $.ajax({
        url: ajaxurl,
        data: {
            'action': 'get_link_data'
        },
        success: function(response) {
            var container = document.getElementById('topic-cluster-network');
            var data = {
                nodes: new vis.DataSet(response.nodes),
                edges: new vis.DataSet(response.edges.map(edge => ({...edge, arrows: 'to'})))
            };
            var options = {
                nodes: {
                    shape: 'box',
                    margin: 10,
                    widthConstraint: {
                        maximum: 200
                    },
                    font: {
                        size: 14,
                        face: 'arial',
                        multi: 'html',
                        align: 'left'
                    },
                    color: {
                        background: '#D2E5FF',
                        border: '#2B7CE9',
                        highlight: {
                            background: '#FFFF00',
                            border: '#2B7CE9'
                        }
                    }
                },
                edges: {
                    width: 1,
                    color: {
                        color: '#2B7CE9',
                        highlight: '#000000'
                    },
                    arrows: {
                        to: {
                            enabled: true,
                            scaleFactor: 0.5
                        }
                    },
                    smooth: {
                        type: 'cubicBezier',
                        forceDirection: 'horizontal',
                        roundness: 0.4
                    }
                },
                physics: {
                    stabilization: true,
                    barnesHut: {
                        gravitationalConstant: -30000,  // 調整
                        springLength: 250,  // 調整
                        springConstant: 0.01,  // 調整
                        damping: 0.09  // 追加
                    }
                },
                layout: {
                    improvedLayout: true,
                    hierarchical: {
                        enabled: false,
                        levelSeparation: 150,
                        nodeSpacing: 100,
                        treeSpacing: 200,
                        blockShifting: true,
                        edgeMinimization: true,
                        parentCentralization: true,
                        direction: 'UD',        // UD, DU, LR, RL
                        sortMethod: 'hubsize'   // hubsize, directed
                    }
                },
                interaction: {
                    hover: true,
                    tooltipDelay: 200,
                    zoomView: true,  // 追加
                    dragView: true   // 追加
                }
            };
            var network = new vis.Network(container, data, options);

            // ノードをクリックしたときの処理
            network.on("doubleClick", function (params) {
                if (params.nodes.length > 0) {
                    var nodeId = params.nodes[0];
                    var clickedNode = data.nodes.get(nodeId);
                    window.open('/' + clickedNode.slug, '_blank');
                }
            });
        }
    });
});
