<?php
/**
 * Plugin Name: Topic Cluster Visualizer
 * Description: Visualizes internal link structure as a topic cluster, including link card recognition
 * Version: 1.4
 * Author: uchilove
 */

// スクリプトとスタイルの読み込み関数は変更なし

// リンクデータを取得する関数を更新
function tcv_get_link_data() {
    $posts = get_posts(array('numberposts' => -1, 'post_status' => 'publish'));
    $nodes = array();
    $edges = array();
    
    foreach ($posts as $post) {
        $nodes[] = array(
            'id' => $post->ID,
            'label' => $post->post_title . "\n(" . $post->post_name . ")",
            'title' => $post->post_title,
            'slug' => $post->post_name,
        );
        
        $content = $post->post_content;
        
        // 通常のリンクを検出
        preg_match_all('/<a\s+(?:[^>]*?\s+)?href="([^"]*)"/', $content, $matches);
        $urls = $matches[1];
        
        // リンクカードのショートコードを検出（例: [card url="..."]）
        preg_match_all('/\[card\s+url="([^"]+)"/i', $content, $card_matches);
        $urls = array_merge($urls, $card_matches[1]);
        
        // リンクカードのHTMLを検出（例: <div class="link-card" data-href="...">）
        preg_match_all('/<div\s+(?:[^>]*?\s+)?class="[^"]*link-card[^"]*"[^>]*data-href="([^"]+)"/', $content, $html_card_matches);
        $urls = array_merge($urls, $html_card_matches[1]);
        
        foreach ($urls as $url) {
            $linked_post_id = url_to_postid($url);
            if ($linked_post_id && $linked_post_id != $post->ID) {  // 自己参照を除外
                $edges[] = array(
                    'from' => $post->ID,
                    'to' => $linked_post_id
                );
            }
        }
    }
    
    return array('nodes' => $nodes, 'edges' => $edges);
}

// AJAXハンドラー、管理メニュー追加、管理ページコンテンツ関数は変更なし

// 以下、他の必要な関数を追加
